// This source code is a part of Project Violet.
// Copyright (C) 2021.violet-team. Licensed under the Apache-2.0 License.

import 'package:violet/script/parser.dart';

class JSonParser extends ShiftReduceParser {
  static const Map<String, int> _symbolTable = {
    "S'": 0,
    "JSON": 1,
    "ARRAY": 2,
    "OBJECT": 3,
    "MEMBERS": 4,
    "PAIR": 5,
    "ELEMENTS": 6,
    "VALUE": 7,
    "object_starts": 8,
    "object_ends": 9,
    "comma": 10,
    "v_pair": 11,
    "array_starts": 12,
    "array_ends": 13,
    "v_true": 14,
    "v_false": 15,
    "v_null": 16,
    "v_string": 17,
    "v_number": 18,
    "\$": 19,
  };

  static const List<List<int>> _table = [
    [0, 1, 3, 2, 0, 0, 0, 0, 4, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 28],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2],
    [0, 0, 0, 0, 7, 8, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 9, 0, 0],
    [0, 0, 16, 15, 0, 0, 11, 12, 4, 0, 0, 0, 5, 10, 17, 18, 19, 13, 14, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, -5, -5, 0, 0, -5, 0, 0, 0, 0, 0, -5],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, 20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, -7, 21, 0, 0, 0, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 22, 0, 0, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, -3, -3, 0, 0, -3, 0, 0, 0, 0, 0, -3],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 23, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 0, 0, -10, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, -12, -12, 0, 0, -12, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, -13, -13, 0, 0, -13, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, -14, -14, 0, 0, -14, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, -15, -15, 0, 0, -15, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, -16, -16, 0, 0, -16, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, -17, -17, 0, 0, -17, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, -18, -18, 0, 0, -18, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, -6, -6, 0, 0, -6, 0, 0, 0, 0, 0, -6],
    [0, 0, 0, 0, 25, 8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 0],
    [0, 0, 16, 15, 0, 0, 0, 26, 4, 0, 0, 0, 5, 0, 17, 18, 19, 13, 14, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, -4, -4, 0, 0, -4, 0, 0, 0, 0, 0, -4],
    [0, 0, 16, 15, 0, 0, 27, 12, 4, 0, 0, 0, 5, 0, 17, 18, 19, 13, 14, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, -8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, -9, -9, 0, 0, 0, 0, 0, 0, 0, 0, 0],
    [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -11, 0, 0, 0, 0, 0, 0],
  ];

  static const List<int> _production = [
    1, 1, 1, 2, 3, 2, 3, 1, 3, 3, 1, 3, 1, 1, 1, 1, 1, 1, 1 //
  ];

  static const List<int> _groupTable = [
    0, 1, 1, 2, 2, 3, 3, 4, 4, 5, 6, 6, 7, 7, 7, 7, 7, 7, 7 //
  ];

  static const int _accept = 28;

  JSonParser()
      : super(
          symbolTable: _symbolTable,
          table: _table,
          production: _production,
          groupTable: _groupTable,
          accept: _accept,
        );
}
